##############################################################################
# Copyright 2023 Alice & Bob
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.
##############################################################################

from typing import Dict, List

from .client import ApiClient


def list_targets(client: ApiClient) -> List[Dict]:
    """Get information about all available targets in the Alice & Bob API

    A target in the APi is the equivalent of a backend in Qiskit parlance.

    Args:
        client (ApiClient): a client for the Alice & Bob API

    Returns:
        List[Dict]: for every target, the description of the target
            capabilities (available options, gate set)
    """
    return client.get('v1/targets/').json()
